@@ -201,10 +201,10 @@ class RayEnv(VectorizedEnvironment):
 
     def reset(self, return_state: bool = True) -> [np.ndarray, tuple]:
         """Restart the environment."""
+        if self.plan_env is None and self.delay_setup:
+            self.setup()
         ray.get([w.reset.remote(return_state=return_state) for w in self.workers])
-        state, obs = self.plan_env.reset(return_state=True)
-        ray.get([w.set_state.remote(state) for w in self.workers])
-        return (state, obs) if return_state else obs
+        return super(RayEnv, self).reset(return_state=return_state)
 
     def sync_states(self, state: None) -> None:
         """
